@@ -19,7 +19,7 @@
  */
 
 /**
- * SECTION:gstqtoverlay
+ * SECTION:element-qmlgloverlay
  *
  * qmlgloverlay provides a way to render an almost-arbitrary QML scene within
  * GStreamer pipeline using the same OpenGL context that GStreamer uses
@@ -145,6 +145,7 @@ enum
   PROP_WIDGET,
   PROP_QML_SCENE,
   PROP_ROOT_ITEM,
+  PROP_DEPTH_AND_STENCIL_BUFFER,
 };
 
 enum
@@ -204,6 +205,23 @@ gst_qt_overlay_class_init (GstQtOverlayClass * klass)
           "The root QQuickItem from the qml-scene used to render",
           (GParamFlags) (G_PARAM_READABLE | G_PARAM_STATIC_STRINGS)));
 
+  /**
+   * GstQtOverlay:depth-buffer:
+   *
+   * Instructs QML to not use a depth or stencil buffer when rendering.
+   *
+   * WARNING: Disabling the depth and stencil buffer may cause QML to
+   * incorrectly render the provided scene.
+   *
+   * Since: 1.26
+   */
+  g_object_class_install_property (gobject_class, PROP_DEPTH_AND_STENCIL_BUFFER,
+      g_param_spec_boolean ("depth-buffer", "Depth and Stencil Buffer",
+          "Use depth and stencil buffer for the rendering of the scene. "
+          "Might corrupt the rendering when set to FALSE! "
+          "Only set to FALSE after carefully checking the targeted QML scene.", TRUE,
+          (GParamFlags) (G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | GST_PARAM_MUTABLE_READY)));
+
   /**
    * GstQmlGLOverlay::qml-scene-initialized
    * @element: the #GstQmlGLOverlay
@@ -243,6 +261,7 @@ static void
 gst_qt_overlay_init (GstQtOverlay * qt_overlay)
 {
   qt_overlay->widget = QSharedPointer<QtGLVideoItemInterface>();
+  qt_overlay->depth_buffer = TRUE;
   qt_overlay->qml_scene = NULL;
 }
 
@@ -278,6 +297,9 @@ gst_qt_overlay_set_property (GObject * object, guint prop_id,
       g_free (qt_overlay->qml_scene);
       qt_overlay->qml_scene = g_value_dup_string (value);
       break;
+    case PROP_DEPTH_AND_STENCIL_BUFFER:
+      qt_overlay->depth_buffer = g_value_get_boolean (value);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -316,6 +338,9 @@ gst_qt_overlay_get_property (GObject * object, guint prop_id,
       }
       GST_OBJECT_UNLOCK (qt_overlay);
       break;
+     case PROP_DEPTH_AND_STENCIL_BUFFER:
+      g_value_set_boolean(value, qt_overlay->depth_buffer);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -341,7 +366,7 @@ gst_qt_overlay_gl_start (GstGLBaseFilter * bfilter)
 
   GST_OBJECT_LOCK (bfilter);
   qt_overlay->renderer = new GstQuickRenderer;
-  if (!qt_overlay->renderer->init (bfilter->context, &error)) {
+  if (!qt_overlay->renderer->init (bfilter->context, qt_overlay->depth_buffer, &error)) {
     GST_ELEMENT_ERROR (GST_ELEMENT (bfilter), RESOURCE, NOT_FOUND,
         ("%s", error->message), (NULL));
     delete qt_overlay->renderer;
