@@ -65,11 +65,8 @@ GST_DEBUG_CATEGORY_STATIC (gst_spectrum_debug);
 #define GST_CAT_DEFAULT gst_spectrum_debug
 
 /* elementfactory information */
-#if G_BYTE_ORDER == G_LITTLE_ENDIAN
-# define FORMATS "{ S16LE, S24LE, S32LE, F32LE, F64LE }"
-#else
-# define FORMATS "{ S16BE, S24BE, S32BE, F32BE, F64BE }"
-#endif
+#define FORMATS "{ " GST_AUDIO_NE (S16) ", " GST_AUDIO_NE (S24) ", " \
+    GST_AUDIO_NE (S32) ", " GST_AUDIO_NE (F32) ", " GST_AUDIO_NE (F64) " }"
 
 #define ALLOWED_CAPS \
   GST_AUDIO_CAPS_MAKE (FORMATS) ", " \
@@ -98,6 +95,8 @@ enum
 
 #define gst_spectrum_parent_class parent_class
 G_DEFINE_TYPE (GstSpectrum, gst_spectrum, GST_TYPE_AUDIO_FILTER);
+GST_ELEMENT_REGISTER_DEFINE (spectrum, "spectrum", GST_RANK_NONE,
+    GST_TYPE_SPECTRUM);
 
 static void gst_spectrum_finalize (GObject * object);
 static void gst_spectrum_set_property (GObject * object, guint prop_id,
@@ -953,8 +952,8 @@ gst_spectrum_transform_ip (GstBaseTransform * trans, GstBuffer * buffer)
 static gboolean
 plugin_init (GstPlugin * plugin)
 {
-  return gst_element_register (plugin, "spectrum", GST_RANK_NONE,
-      GST_TYPE_SPECTRUM);
+
+  return GST_ELEMENT_REGISTER (spectrum, plugin);
 }
 
 GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
